@@ -15,7 +15,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.61 2004/03/02 05:37:36 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Glib.pm,v 1.62.2.3 2004/03/24 01:09:54 muppetman Exp $
 #
 
 package Glib;
@@ -61,7 +61,7 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{all} = \@EXPORT_OK;
 
-our $VERSION = '1.038';
+our $VERSION = '1.040';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -108,7 +108,7 @@ sub TIESCALAR
 
 sub STORE { croak 'property '.$_[0][1].' is read-only'; }
 
-sub FETCH { croak 'property '.$_[0][1].' is write-only'; }
+sub FETCH { '[write-only]'; }
 
 package Glib::Object::Property::Readable;
 
@@ -502,7 +502,8 @@ the sourcecode of the original gtk-perl and pygtk projects.  Marc Lehmann
 E<lt>pcg at goof dot comE<gt> did lots of great work on the magic of making
 Glib::Object wrapper and subclassing work like they should.  Ross McFarland
 <rwmcfa1 at neces dot com> wrote quite a bit of the documentation generation
-tools.
+tools.  Torsten Schoenfeld <kaffeetisch at web dot de> contributed little
+patches and tests here and there.
 
 =head1 COPYRIGHT AND LICENSE
 
