@@ -1,10 +1,10 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/MakeHelper.pm,v 1.26 2004/02/25 20:21:22 rwmcfa1 Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/MakeHelper.pm,v 1.28.2.2 2004/03/17 06:02:37 muppetman Exp $
 #
 
 package Glib::MakeHelper;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -216,7 +216,38 @@ sub postamble_docs_full {
 	if (UNIVERSAL::isa ($params{DEPENDS}, 'ExtUtils::Depends')) {
 		my $dep = $params{DEPENDS};
 
-		# fetch list of XS files from depends object
+		# fetch list of XS files from depends object.
+		# HACK ALERT: the older versions of ExtUtils::Depends
+		# (<0.2) use a different key layout and don't store enough
+		# metadata about the dependencies, so we require >=0.2;
+		# however, the older versions don't support import version
+		# checking (in fact they don't support version-checking at
+		# all), so the "use" test in a Makefile.PL can't tell if
+		# it has loaded a new enough version!
+		# the rewrite at version 0.200 added the get_dep() method,
+		# which we use, so let's check for that.
+		unless (defined &ExtUtils::Depends::get_deps) {
+			use ExtUtils::MakeMaker;
+			warn "ExtUtils::Depends is too old, need at "
+			   . "least version 0.2";
+			# this is so that CPAN builds will do the upgrade
+			# properly.
+			WriteMakefile(
+				PREREQ_FATAL => 1,
+				PREREQ_PM => { 'ExtUtils::Depends' => 0.2, },
+			);
+			exit 1; # not reached.
+		}
+		# continue with the excessive validation...
+		croak "value of DEPENDS key must be an ExtUtils::Depends object"
+			unless UNIVERSAL::isa $dep, 'ExtUtils::Depends';
+		croak "corrupt or invalid ExtUtils::Depends instance -- "
+		    . "the xs key is "
+		    .(exists ($dep->{xs}) ? "missing" : "broken")."!"
+			unless exists $dep->{xs}
+			   and 'ARRAY' eq ref $dep->{xs};
+
+		# finally, *this* is what we wanted.
 		@xs_files = @{$dep->{xs}};
 
 		# fetch doctypes files from the depends' dependencies.
@@ -264,19 +295,38 @@ sub postamble_docs_full {
 
 	#warn "docgen_code: $docgen_code\n";
 
-"
-
-# BLIB_DONE should be set to something we can depend on that will ensure that
-# we are safe to link against an up to date module out of blib. basically what
-# we need to wait on is the static/dynamic lib file to be created. the
-# following trick is intended to handle both of those cases without causing the
-# other to happen.
-BLIB_DONE=
+	# BLIB_DONE should be set to something we can depend on that will
+	# ensure that we are safe to link against an up to date module out
+	# of blib. basically what we need to wait on is the static/dynamic
+	# lib file to be created. the following trick is intended to handle
+	# both of those cases without causing the other to happen.
+	my $blib_done;
+	# this is very sloppy, because different makes have different
+	# conditional syntaxes.
+	use Config;
+	if ($Config{make} eq 'nmake') {
+		warn "loathe nmake.\n";
+		$blib_done = "
+!If \"\$(LINKTYPE)\" == \"dynamic\"
+BLIB_DONE=\$(INST_DYNAMIC)
+!ELSE
+BLIB_DONE=\$(INST_STATIC)
+!ENDIF
+";
+	} else {
+		# assuming GNU Make
+		$blib_done = "
 ifeq (\$(LINKTYPE), dynamic)
 	BLIB_DONE=\$(INST_DYNAMIC)
 else
 	BLIB_DONE=\$(INST_STATIC)
 endif
+";
+	}
+
+"
+BLIB_DONE=
+$blib_done
 
 # documentation stuff
 build/doc.pl :: Makefile @xs_files
@@ -293,7 +343,7 @@ build/podindex :: \$(BLIB_DONE) Makefile build/doc.pl
 		-e '$docgen_code'
 
 \$(INST_LIB)/\$(FULLEXT)/:
-	mkdir -p \$@
+	$^X -MExtUtils::Command -e mkpath \$@
 
 \$(INST_LIB)/\$(FULLEXT)/index.pod :: \$(INST_LIB)/\$(FULLEXT)/ build/podindex
 	$^X -e 'print \"\\n=head1 NAME\\n\\n\$(NAME) API Reference Pod Index\\n\\n=head1 PAGES\\n\\n=over\\n\\n\"' \\
@@ -385,6 +435,7 @@ inserted by this module under the name MY::const_cccmd to fix this issue.
 
 sub const_cccmd {
 	my $inherited = shift->SUPER::const_cccmd (@_);
+	return '' unless $inherited;
 	use Config;
 	# a more sophisticated match may be necessary, but this works for me.
 	if ($Config{cc} eq "cl") {
@@ -398,8 +449,6 @@ sub const_cccmd {
 
 1;
 
-=back
-
 =head1 AUTHOR
 
 Ross McFarland E<lt>rwmcfa1 at neces dot comE<gt>
