@@ -1,5 +1,5 @@
-# Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the full
-# list)
+# Copyright (C) 2003-2004 by the gtk2-perl team (see the file AUTHORS for
+# the full list)
 # 
 # This library is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Library General Public License as published by the Free
@@ -15,12 +15,12 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Subclass.pm,v 1.7 2003/12/30 16:46:22 rwmcfa1 Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Glib/Subclass.pm,v 1.10 2004/02/17 20:26:31 muppetman Exp $
 #
 
 package Glib::Object::Subclass;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Glib;
 
@@ -204,9 +204,6 @@ sub import {
    my ($self, $superclass, %arg) = @_;
    my $class = caller;
 
-   my $signals    = $arg{signals}    || {};
-   my $properties = $arg{properties} || [];
-
    # the CHECK callback will be executed after the module is compiled
    my $check = sub {
       # "optionally" supply defaults
@@ -217,10 +214,9 @@ sub import {
    };
    eval "package $class; CHECK { &\$check }";
 
-   Glib::Type->register(
+   Glib::Type->register_object(
       $superclass, $class,
-      signals    => $signals,
-      properties => $properties,
+      %arg,
    );
 }
 
@@ -337,7 +333,7 @@ Marc Lehmann E<lt>pcg@goof.comE<gt>, muppet E<lt>scott at asofyet dot orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by muppet and the gtk2-perl team
+Copyright 2003-2004 by muppet and the gtk2-perl team
 
 This library is free software; you can redistribute it and/or modify
 it under the terms of the Lesser General Public License (LGPL).  For 
